summaryrefslogtreecommitdiffstats
path: root/testsuites/psxtests/psxmsgq01/init.c
diff options
context:
space:
mode:
Diffstat (limited to 'testsuites/psxtests/psxmsgq01/init.c')
-rw-r--r--testsuites/psxtests/psxmsgq01/init.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/testsuites/psxtests/psxmsgq01/init.c b/testsuites/psxtests/psxmsgq01/init.c
index de2965a715..41cb1243aa 100644
--- a/testsuites/psxtests/psxmsgq01/init.c
+++ b/testsuites/psxtests/psxmsgq01/init.c
@@ -378,13 +378,13 @@ void validate_mq_unlink_error_codes(void)
fatal_posix_service_status( errno, EINVAL, "mq_unlink errno value");
/*
* EINVAL - Unlink a queue with a null name
*/
- puts( "Init: mq_unlink (\"\") - EINVAL" );
+ puts( "Init: mq_unlink (\"\") - ENOENT" );
status = mq_unlink( "" );
fatal_posix_service_status( status, -1, "mq_unlink error return status");
- fatal_posix_service_status( errno, EINVAL, "mq_unlink errno value");
+ fatal_posix_service_status( errno, ENOENT, "mq_unlink errno value");
}
void validate_mq_close_error_codes(void)
@@ -378,13 +378,13 @@ void validate_mq_unlink_error_codes(void)
fatal_posix_service_status( errno, EINVAL, "mq_unlink errno value");
/*
- * EINVAL - Unlink a queue with a null name
+ * ENOENT - Unlink a queue with a zero length name
*/